@@ -27,7 +27,9 @@
 
 #include <QDebug>
 #include <QDirIterator>
+#include <QFile>
 #include <QFileDialog>
+#include <QFileInfo>
 #include <QProcess>
 #include <QRegularExpression>
 #include <QResizeEvent>
@@ -40,9 +42,10 @@
 
 #include "about.h"
 #include "flatbutton.h"
-#include "version.h"
 #include <unistd.h>
 
+
+
 MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
     : QDialog(parent),
       ui(new Ui::MainWindow),
@@ -50,6 +53,8 @@ MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
 {
     ui->setupUi(this);
     setConnections();
+    connect(&fileWatcher, &QFileSystemWatcher::fileChanged, this, &MainWindow::handleFileChanged);
+    connect(&fileWatcher, &QFileSystemWatcher::directoryChanged, this, &MainWindow::handleDirectoryChanged);
 
     if (arg_parser.isSet("remove-checkbox")) {
         ui->checkBoxStartup->hide();
@@ -62,6 +67,7 @@ MainWindow::MainWindow(const QCommandLineParser &arg_parser, QWidget *parent)
     file_name = !argList.isEmpty() && QFile(argList.first()).exists() ? argList.first() : getFileName();
 
     readFile(file_name);
+    watchFile(file_name);
     setGui();
 }
 
@@ -91,7 +97,7 @@ QIcon MainWindow::findIcon(const QString &iconName)
                                           "/usr/share/icons/Adwaita/48x48/legacy/"};
 
     // Helper function to search for icon in all paths
-    static const auto searchInPaths = [&](const QString &name) -> QIcon {
+    static const auto searchInPaths = [](const QString &name) -> QIcon {
         for (const auto &path : searchPaths) {
             const QString fullPath = QDir(path).filePath(name);
             if (QFile::exists(fullPath)) {
@@ -171,9 +177,8 @@ QIcon MainWindow::findIcon(const QString &iconName)
     }
 
     // Fall back to the default icon if nothing else was found.
-    QIcon result = getDefaultIcon();
-    // iconCache[iconName] = result;
-    return result;
+    // Note: Default icons are not cached to allow future resolution of actual icons
+    return getDefaultIcon();
 }
 
 // Strip %f, %F, %U, etc. if exec expects a file name since it's called without an argument from this launcher.
@@ -202,11 +207,11 @@ void MainWindow::setup()
 
     QSettings settings("/etc/custom-toolbox/custom-toolbox.conf", QSettings::NativeFormat);
     hideGUI = settings.value("hideGUI", false).toBool();
-    min_height = settings.value("min_height").toInt();
-    min_width = settings.value("min_width").toInt();
+    min_height = qBound(300, settings.value("min_height").toInt(), 3000);
+    min_width = qBound(300, settings.value("min_width").toInt(), 3000);
     gui_editor = settings.value("gui_editor").toString();
-    fixed_number_col = settings.value("fixed_number_columns", 0).toInt();
-    int size = settings.value("icon_size", default_icon_size).toInt();
+    fixed_number_col = qBound(0, settings.value("fixed_number_columns", 0).toInt(), 20);
+    int size = qBound(8, settings.value("icon_size", default_icon_size).toInt(), 1024);
     icon_size = {size, size};
 }
 
@@ -242,6 +247,10 @@ void MainWindow::setGui()
 void MainWindow::btn_clicked()
 {
     const QString cmd = sender()->property("cmd").toString();
+    if (cmd.trimmed().isEmpty()) {
+        QMessageBox::warning(this, tr("Execution Error"), tr("Command is empty. Cannot execute."));
+        return;
+    }
     // pkexec cannot take &, it would block the GUI that's why we need to hide it
     if (hideGUI || cmd.startsWith("pkexec")) {
         hide();
@@ -555,6 +564,7 @@ void MainWindow::readFile(const QString &file_name)
     categories.clear();
     categories.reserve(20); // Reserve space for typical number of categories
     category_map.clear();
+    icon_theme.clear();
 
     QFile file(file_name);
     if (!file.exists()) {
@@ -657,7 +667,7 @@ void MainWindow::pushAbout_clicked()
                   "<p align=\"center\"><h3>%4</h3></p>"
                   "<p align=\"center\"><a href=\"http://mxlinux.org\">http://mxlinux.org</a><br /></p>"
                   "<p align=\"center\">%5<br /><br /></p>")
-              .arg(windowTitle(), tr("Version:"), VERSION,
+              .arg(windowTitle(), tr("Version:"), QApplication::applicationVersion(),
                    tr("Custom Toolbox is a tool used for creating a custom launcher"), tr("Copyright (c) MX Linux"));
 
     displayAboutMsgBox(tr("About %1").arg(windowTitle()), aboutText, "/usr/share/doc/custom-toolbox/license.html",
@@ -712,7 +722,7 @@ void MainWindow::checkBoxStartup_clicked(bool checked)
             out << "[Desktop Entry]\n"
                 << "Name=" << windowTitle() << '\n'
                 << "Comment=" << ui->commentLabel->text() << '\n'
-                << "Exec=custom-toolbox " << file_location << '/' << custom_name << ".list\n"
+                << "Exec=custom-toolbox \"" << file_location << '/' << custom_name << ".list\"\n"
                 << "Terminal=false\n"
                 << "Type=Application\n"
                 << "Icon=custom-toolbox\n"
@@ -735,16 +745,22 @@ void MainWindow::pushEdit_clicked()
                          : gui_editor;
 
     QStringList cmdList = buildEditorCommand(editor) << editor << file_name;
-    QProcess::execute("/bin/sh", {"-c", cmdList.join(' ')});
-    readFile(file_name);
-    setGui();
+    int exitCode = QProcess::execute("/bin/sh", {"-c", cmdList.join(' ')});
+    if (exitCode != 0) {
+        QMessageBox::warning(this, tr("Error"), tr("Editor command failed with code %1").arg(exitCode));
+    }
+    refreshIfFileChanged();
+    watchFile(file_name);
 }
 
 QString MainWindow::getDefaultEditor()
 {
     QProcess proc;
     proc.start("xdg-mime", {"query", "default", "text/plain"});
-    proc.waitForFinished();
+    if (!proc.waitForFinished(3000) || proc.exitCode() != 0) {
+        qWarning() << "xdg-mime failed to query default editor";
+        return "nano"; // Fallback to nano
+    }
     QString default_editor = proc.readAllStandardOutput().trimmed();
     QString desktop_file
         = QStandardPaths::locate(QStandardPaths::ApplicationsLocation, default_editor, QStandardPaths::LocateFile);
@@ -791,3 +807,62 @@ QStringList MainWindow::buildEditorCommand(const QString &editor)
 
     return editorCommands;
 }
+
+void MainWindow::handleFileChanged(const QString &path)
+{
+    if (path != file_name) {
+        return;
+    }
+
+    refreshIfFileChanged();
+    watchFile(file_name);
+}
+
+void MainWindow::handleDirectoryChanged(const QString &path)
+{
+    const QString currentDirectory = QFileInfo(file_name).absolutePath();
+    if (path != currentDirectory) {
+        return;
+    }
+
+    refreshIfFileChanged();
+
+    if (QFile::exists(file_name)) {
+        watchFile(file_name);
+    }
+}
+
+void MainWindow::refreshIfFileChanged()
+{
+    QFileInfo info(file_name);
+    if (!info.exists()) {
+        return;
+    }
+
+    readFile(file_name);
+    setGui();
+}
+
+void MainWindow::watchFile(const QString &path)
+{
+    if (path.isEmpty()) {
+        return;
+    }
+
+    if (fileWatcher.files().contains(path)) {
+        fileWatcher.removePath(path);
+    }
+
+    if (QFile::exists(path)) {
+        if (!fileWatcher.addPath(path)) {
+            qWarning() << "Failed to add watch for file:" << path;
+        }
+    }
+
+    const QString directoryPath = QFileInfo(path).absolutePath();
+    if (!directoryPath.isEmpty() && !fileWatcher.directories().contains(directoryPath)) {
+        if (!fileWatcher.addPath(directoryPath)) {
+            qWarning() << "Failed to add watch for directory:" << directoryPath;
+        }
+    }
+}
